@@ -10,6 +10,7 @@ from .event_helpers import (
     expect_event,
     add_event,
     add_raw_event,
+    get_event,
     get_all_events,
     delete_all_matching_events,
     get_all_matching_events,
@@ -30,6 +31,7 @@ __all__ = [
     "delete_all_matching_events",
     "dont_expect_event",
     "expect_event",
+    "get_event",
     "get_all_events",
     "get_all_matching_events",
     "log_event_store",
